@@ -22,8 +22,8 @@
 
 #include <config.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
 
 
 static void 
